import HeroSection from '@/components/HeroSection';
import PartnershipsSection from '@/components/PartnershipsSection';
import InlineCTA from '@/components/InlineCTA';
import LazySection from '@/components/LazySection';
import SocialProofTicker from '@/components/SocialProofTicker';
import ExitIntentPopup from '@/components/ExitIntentPopup';
import StickyTimerBanner from '@/components/StickyTimerBanner';
import InstagramTicker from '@/components/InstagramTicker';
import ChatWithChamba from '@/components/ChatWithChamba';
import ChambaStorySection from '@/components/ChambaStorySection';
import { useScrollTracking } from '@/hooks/useScrollTracking';
import { useDropOffTracking } from '@/hooks/useDropOffTracking';
import { useAdaptiveLoading } from '@/hooks/useAdaptiveLoading';
import { lazy, Suspense } from 'react';

// Lazy load heavy components
const WinGallery = lazy(() => import('@/components/WinGallery'));
const CustomerSuccessStory = lazy(() => import('@/components/CustomerSuccessStory'));
const TestimonialsSection = lazy(() => import('@/components/TestimonialsSection'));
const FAQSection = lazy(() => import('@/components/FAQSection'));
const Footer = lazy(() => import('@/components/Footer'));

// Import PurchaseSection directly (not lazy) so CTA buttons work immediately
import PurchaseSection from '@/components/PurchaseSection';

const Index = () => {
  useScrollTracking();
  useDropOffTracking();
  const adaptiveSettings = useAdaptiveLoading();

  return (
    <div className="min-h-screen bg-background">
      {/* Sticky Timer Banner */}
      <StickyTimerBanner />
      
      {/* Instagram Ticker */}
      <InstagramTicker />
      
      {/* Main Content */}
      <div className="pt-24">
      {/* Hero Section with Countdown & Social Proof */}
      <div data-section="hero">
        <HeroSection />
      </div>
      
      {/* Partnerships */}
      <div data-section="partnerships">
        <PartnershipsSection />
      </div>
      
      {/* First CTA after partnerships */}
      <InlineCTA variant="primary" />
      
      {/* Win Gallery / Screenshots - Lazy Loaded */}
      <LazySection>
        <Suspense fallback={<div className="min-h-[600px] bg-muted/20 animate-pulse" />}>
          <div data-section="win-gallery">
            <WinGallery />
          </div>
        </Suspense>
      </LazySection>
      
      {/* Customer Success Story - Lazy Loaded */}
      <LazySection>
        <Suspense fallback={<div className="min-h-[600px] bg-muted/20 animate-pulse" />}>
          <div data-section="customer-success">
            <CustomerSuccessStory />
          </div>
        </Suspense>
      </LazySection>
      
      {/* Second CTA after success story */}
      <InlineCTA variant="secondary" text="🏆 GET MAX PLAY - $299" />
      
      {/* Customer Testimonials - Lazy Loaded */}
      <LazySection>
        <Suspense fallback={<div className="min-h-[400px] bg-muted/20 animate-pulse" />}>
          <div data-section="testimonials">
            <TestimonialsSection />
          </div>
        </Suspense>
      </LazySection>
      
      {/* Chamba's Personal Story */}
      <div data-section="chamba-story">
        <ChambaStorySection />
      </div>
      
      {/* Urgent CTA before purchase */}
      <InlineCTA variant="urgent" />
      
      {/* Purchase Section - Not lazy loaded for immediate CTA functionality */}
      <div data-section="purchase" id="purchase">
        <PurchaseSection />
      </div>
      
      {/* FAQ - Lazy Loaded */}
      <LazySection>
        <Suspense fallback={<div className="min-h-[400px] bg-muted/20 animate-pulse" />}>
          <FAQSection />
        </Suspense>
      </LazySection>
      
      {/* Final CTA after FAQ */}
      <InlineCTA variant="primary" text="Last Chance - Click Here" />
      
      {/* Footer - Lazy Loaded */}
      <LazySection>
        <Suspense fallback={<div className="min-h-[200px] bg-muted/20 animate-pulse" />}>
          <Footer />
        </Suspense>
      </LazySection>
      
      {/* Conversion Optimization Components */}
      <ExitIntentPopup />
      
      {/* Chat with Chamba */}
      <ChatWithChamba />
      
      {/* Sticky Social Proof Ticker */}
      <SocialProofTicker />
      </div>
    </div>
  );
};

export default Index;
